==> unicore-unicorex6_5.0.0.orig.tar.gz: uas-core/src/test/resources/dcatalogue/db/schema_mysql.sql <==
SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";

DROP TABLE IF EXISTS `ldas_to_update`, `ldas`, `files`, `smses`, `dsmses`;

CREATE TABLE IF NOT EXISTS `dsmses` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `identifier` varchar(64) NOT NULL,
  `owner_dn` varchar(512) NULL,
  PRIMARY KEY (`id`),
  KEY `identifier` (`identifier`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8  AUTO_INCREMENT=2;
INSERT INTO `dsmses` (`id`, `identifier`) VALUES (1, 'main');

CREATE TABLE IF NOT EXISTS `smses` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `dsms_id` int(11) NOT NULL,
  `sms_epr` varchar(512) NULL,
  `factory_epr` varchar(512) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `factory_epr` (`factory_epr`),
  FOREIGN KEY (`dsms_id`) REFERENCES `dsmses` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

CREATE TABLE IF NOT EXISTS `files` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `filename` varchar(128) NOT NULL,
  `full_path` varchar(1024) NOT NULL,
  `full_path_md5` varchar(32) NOT NULL,
  `parent_id` int(11) NOT NULL,
  `directory` tinyint(1) NOT NULL,
  `dsms_id` int(11) NOT NULL,
  `owner_dn` varchar(512) NULL,
  PRIMARY KEY (`id`),
  KEY `parent_id` (`parent_id`),
  KEY `path_dir` (`directory`, `dsms_id`, `full_path_md5`),
  KEY `path` (`dsms_id`, `full_path_md5`),
  FOREIGN KEY (`dsms_id`) REFERENCES `dsmses` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2;

INSERT INTO `files` (`id`, `filename`, `full_path`, `full_path_md5`, `parent_id`, `directory`, `dsms_id`) VALUES
(1, '', '', 'd41d8cd98f00b204e9800998ecf8427e', 0, 1, 1);

CREATE TABLE IF NOT EXISTS `ldas` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `file_id` int(11) NOT NULL,
  `sms` varchar(512) NULL,
  `filename` varchar(512) NOT NULL,
  `directory` tinyint(1) NOT NULL,
  FOREIGN KEY (`file_id`) REFERENCES `files` (`id`) ON DELETE CASCADE,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

CREATE TABLE IF NOT EXISTS `ldas_to_update` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lda_id` int(11) NOT NULL,
  `sms_id` int(11) NOT NULL,
  PRIMARY KEY (id),
  FOREIGN KEY (`lda_id`) REFERENCES `ldas` (`id`) ON DELETE CASCADE,
  FOREIGN KEY (`sms_id`) REFERENCES `smses` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

==> unicore-unicorex6_5.1.0.orig.tar.gz: uas-core/src/test/resources/dcatalogue/db/schema_mysql.sql <==
SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";

DROP TABLE IF EXISTS `ldas`, `owners_files`, `files`, `smses`, `dsmses`, `owners`;

CREATE TABLE IF NOT EXISTS `owners` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `owner_dn` varchar(512) NULL,
  PRIMARY KEY (`id`),
  KEY `owner_dn` (`owner_dn`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

CREATE TABLE IF NOT EXISTS `dsmses` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `identifier` varchar(64) NOT NULL,
  `owner_id` int(11) NULL,
  `root` varchar(1024) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `identifier` (`identifier`),
  FOREIGN KEY (`owner_id`) REFERENCES `owners` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

CREATE TABLE IF NOT EXISTS `smses` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `dsms_id` int(11) NOT NULL,
  `sms_epr` varchar(512) NULL,
  `factory_epr` varchar(512) NULL,
  `tsf_epr` varchar(512) NULL,
  PRIMARY KEY (`id`),
  KEY `factory_epr` (`factory_epr`),
  FOREIGN KEY (`dsms_id`) REFERENCES `dsmses` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

CREATE TABLE IF NOT EXISTS `files` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `filename` varchar(128) NOT NULL,
  `full_path` varchar(1024) NOT NULL,
  `full_path_md5` varchar(32) NOT NULL,
  `parent_id` int(11) NOT NULL,
  `directory` tinyint(1) NOT NULL,
  `dsms_id` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `parent_id` (`parent_id`),
  KEY `path_dir` (`directory`, `dsms_id`, `full_path_md5`),
  KEY `path` (`dsms_id`, `full_path_md5`),
  FOREIGN KEY (`dsms_id`) REFERENCES `dsmses` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

CREATE TABLE IF NOT EXISTS `ldas` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `file_id` int(11) NOT NULL,
  `sms_id` int(11) NOT NULL,
  `filename` varchar(512) NOT NULL,
  `directory` tinyint(1) NOT NULL,
  FOREIGN KEY (`file_id`) REFERENCES `files` (`id`) ON DELETE CASCADE,
  FOREIGN KEY (`sms_id`) REFERENCES `smses` (`id`) ON DELETE CASCADE,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

CREATE TABLE IF NOT EXISTS `owners_files` (
  `owner_id` int(11) NOT NULL,
  `file_id` int(11) NOT NULL,
  PRIMARY KEY (owner_id, file_id),
  FOREIGN KEY (`owner_id`) REFERENCES `owners` (`id`) ON DELETE CASCADE,
  FOREIGN KEY (`file_id`) REFERENCES `files` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;
